@@ -8,7 +8,7 @@ package Stable::Module;
 # Copyright (c) 2014, 2016, 2017, 2018, 2019, 2023 INABA Hitoshi <ina@cpan.org> in a CPAN
 ######################################################################
 
-$VERSION = '0.10';
+$VERSION = '0.11';
 $VERSION = $VERSION;
 
 use 5.00503;
@@ -20,9 +20,6 @@ use IO::File;
 
 use vars qw($re_char $hide_stderr);
 
-# set OSNAME
-my $OSNAME = $^O;
-
 #---------------------------------------------------------------------
 sub VERSION {
     my($self,$version) = @_;
@@ -51,20 +48,37 @@ sub import {
         die "Incorrect use of module '${\__PACKAGE__}' at $filename line $line.\n";
     }
 
-    # codepoint regexp
+    # get /./ (dot: one character) regexp
+    $re_char = qr/[\x00-\xFF]/;
+
+    # Code Page Identifiers (Microsoft Windows)
+    # Identifier .NET Name Additional information
     my %re_char = (
-        'sjis'      => qr{[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[\x00-\xFF]},
-        'gbk'       => qr{[\x81-\xFE][\x00-\xFF]|[\x00-\xFF]},
-        'uhc'       => qr{[\x81-\xFE][\x00-\xFF]|[\x00-\xFF]},
-        'big5'      => qr{[\x81-\xFE][\x00-\xFF]|[\x00-\xFF]},
-        'big5hkscs' => qr{[\x81-\xFE][\x00-\xFF]|[\x00-\xFF]},
-        'eucjp'     => qr{[\xA1-\xFE][\x00-\xFF]|[\x00-\xFF]},
-        'gb18030'   => qr{[\x81-\xFE][\x30-\x39][\x81-\xFE][\x30-\x39]|[\x81-\xFE][\x00-\xFF]|[\x00-\xFF]},
-        'utf8'      => qr{[\xC2-\xDF][\x80-\xBF]|[\xE0-\xEF][\x80-\xBF][\x80-\xBF]|[\xF0-\xF4][\x80-\xBF][\x80-\xBF][\x80-\xBF]|[\x00-\xFF]},
+
+        # Sjis     shift_jis ANSI/OEM Japanese; Japanese (Shift-JIS)
+          '932' => qr{[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[\x00-\xFF]},
+
+        # GBK      gb2312 ANSI/OEM Simplified Chinese (PRC, Singapore); Chinese Simplified (GB2312)
+          '936' => qr{[\x81-\xFE][\x00-\xFF]|[\x00-\xFF]},
+
+        # UHC      ks_c_5601-1987 ANSI/OEM Korean (Unified Hangul Code)
+          '949' => qr{[\x81-\xFE][\x00-\xFF]|[\x00-\xFF]},
+
+        # Big5Plus big5 ANSI/OEM Traditional Chinese (Taiwan; Hong Kong SAR, PRC); Chinese Traditional (Big5)
+          '950' => qr{[\x81-\xFE][\x00-\xFF]|[\x00-\xFF]},
+
+        # Big5HKSCS HKSCS support on top of traditional Chinese Windows
+          '951' => qr{[\x81-\xFE][\x00-\xFF]|[\x00-\xFF]},
+
+        # GB18030  GB18030 Windows XP and later: GB18030 Simplified Chinese (4 byte); Chinese Simplified (GB18030)
+        '54936' => qr{[\x81-\xFE][\x30-\x39][\x81-\xFE][\x30-\x39]|[\x81-\xFE][\x00-\xFF]|[\x00-\xFF]},
     );
 
-    # get /./ (dot: one character) regexp
-    $re_char = ($re_char{detect_system_encoding()} || qr/[\x00-\xFF]/);
+    my $codepage = 'File System Safe';
+    if ($^O =~ m{\A (?:MSWin32|NetWare|symbian|dos) \z}oxms) {
+        $codepage = (qx{chcp} =~ m{ ([0-9]{3,5}) \Z}oxms)[0];
+        $re_char = $re_char{$codepage} || $re_char;
+    }
 
     no strict 'refs';
 
@@ -86,7 +100,7 @@ sub import {
 
     # use File::Basename qw(fileparse basename dirname);
     # use internal routines always for compatibility -- for example, perl 5.6 has incompatible File::Basename
-    if (defined $re_char) {
+    if (1 or exists $re_char{$codepage}) {
         $INC{'File/Basename.pm'} = join '/', $FindBin::Bin, __FILE__;
         *{$caller.'::fileparse'} = \&_fileparse;
         *{$caller.'::basename'}  = \&_basename;
@@ -100,7 +114,7 @@ sub import {
     }
 
     # use File::Path qw(mkpath rmtree);
-    if (defined $re_char) {
+    if (exists $re_char{$codepage}) {
         $INC{'File/Path.pm'}  = join '/', $FindBin::Bin, __FILE__;
         *{$caller.'::mkpath'} = \&_mkpath;
         *{$caller.'::rmtree'} = \&_rmtree;
@@ -112,7 +126,7 @@ sub import {
     }
 
     # use File::Copy qw(copy move);
-    if (defined $re_char) {
+    if (exists $re_char{$codepage}) {
         $INC{'File/Copy.pm'} = join '/', $FindBin::Bin, __FILE__;
         *{$caller.'::copy'}  = \&_copy;
         *{$caller.'::move'}  = \&_move;
@@ -171,131 +185,6 @@ sub unimport {
     # nothing
 }
 
-#---------------------------------------------------------------------
-# detect system encoding any of big5, big5hkscs, eucjp, gb18030, gbk, rfc2279, sjis, uhc, utf8, wtf8
-sub detect_system_encoding {
-
-    # running on Microsoft Windows
-    if ($OSNAME =~ /MSWin32/) {
-        if (my($system_encoding) = qx{chcp} =~ m/[^0123456789](932|936|949|950|951|20932|54936)\Z/) {
-            return {qw(
-                932   sjis
-                936   gbk
-                949   uhc
-                950   big5
-                951   big5hkscs
-                20932 eucjp
-                54936 gb18030
-            )}->{$system_encoding};
-        }
-        else {
-            return 'utf8';
-        }
-    }
-
-    # running on Oracle Solaris
-    elsif ($OSNAME =~ /solaris/) {
-        my $LANG =
-            defined($ENV{'LC_ALL'})   ? $ENV{'LC_ALL'}   :
-            defined($ENV{'LC_CTYPE'}) ? $ENV{'LC_CTYPE'} :
-            defined($ENV{'LANG'})     ? $ENV{'LANG'}     :
-            '';
-        return {qw(
-            ja_JP.PCK     sjis
-            ja            eucjp
-            japanese      eucjp
-            ja_JP.eucJP   eucjp
-            zh            gbk
-            zh.GBK        gbk
-            zh_CN.GBK     gbk
-            zh_CN.EUC     gbk
-            zh_CN.GB18030 gb18030
-            ko            uhc
-            ko_KR.EUC     uhc
-            zh_TW.BIG5    big5
-            zh_HK.BIG5HK  big5hkscs
-        )}->{$LANG} || 'utf8';
-    }
-
-    # running on HP HP-UX
-    elsif ($OSNAME =~ /hpux/) {
-        my $LANG =
-            defined($ENV{'LC_ALL'})   ? $ENV{'LC_ALL'}   :
-            defined($ENV{'LC_CTYPE'}) ? $ENV{'LC_CTYPE'} :
-            defined($ENV{'LANG'})     ? $ENV{'LANG'}     :
-            '';
-        return {qw(
-            japanese      sjis
-            ja_JP.SJIS    sjis
-            japanese.euc  eucjp
-            ja_JP.eucJP   eucjp
-            zh_CN.hp15CN  gbk
-            zh_CN.gb18030 gb18030
-            ko_KR.eucKR   uhc
-            zh_TW.big5    big5
-            zh_HK.big5    big5hkscs
-            zh_HK.hkbig5  big5hkscs
-        )}->{$LANG} || 'utf8';
-    }
-
-    # running on IBM AIX
-    elsif ($OSNAME =~ /aix/) {
-        my $LANG =
-            defined($ENV{'LC_ALL'})   ? $ENV{'LC_ALL'}   :
-            defined($ENV{'LC_CTYPE'}) ? $ENV{'LC_CTYPE'} :
-            defined($ENV{'LANG'})     ? $ENV{'LANG'}     :
-            '';
-        return {qw(
-            Ja_JP            sjis
-            Ja_JP.IBM-943    sjis
-            ja_JP            eucjp
-            ja_JP.IBM-eucJP  eucjp
-            zh_CN            gbk
-            zh_CN.IBM-eucCN  gbk
-            Zh_CN            gb18030
-            Zh_CN.GB18030    gb18030
-            ko_KR            uhc
-            ko_KR.IBM-eucKR  uhc
-            Zh_TW            big5
-            Zh_TW.big-5      big5
-            Zh_HK            big5hkscs
-            Zh_HK.BIG5-HKSCS big5hkscs
-        )}->{$LANG} || 'utf8';
-    }
-
-    # running on Other Systems
-    else {
-        my $LANG =
-            defined($ENV{'LC_ALL'})   ? $ENV{'LC_ALL'}   :
-            defined($ENV{'LC_CTYPE'}) ? $ENV{'LC_CTYPE'} :
-            defined($ENV{'LANG'})     ? $ENV{'LANG'}     :
-            '';
-        return {qw(
-            japanese      sjis
-            ja_JP.SJIS    sjis
-            ja_JP.mscode  sjis
-            ja            eucjp
-            japan         eucjp
-            japanese.euc  eucjp
-            Japanese-EUC  eucjp
-            ja_JP         eucjp
-            ja_JP.ujis    eucjp
-            ja_JP.eucJP   eucjp
-            ja_JP.AJEC    eucjp
-            ja_JP.EUC     eucjp
-            Jp_JP         eucjp
-            zh_CN.EUC     gbk
-            zh_CN.GB2312  gbk
-            zh_CN.hp15CN  gbk
-            zh_CN.gb18030 gb18030
-            ko_KR.eucKR   uhc
-            zh_TW.Big5    big5
-            zh_TW.big5    big5
-            zh_HK.big5    big5hkscs
-        )}->{$LANG} || 'utf8';
-    }
-}
-
 #---------------------------------------------------------------------
 sub _fileparse {
     my($fullname,@suffixlist) = @_;
